/*
 * Copyright (C) 2022  Aravinth Manivannan <realaravinth@batsense.net>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
use actix_web::*;
use serde::{Deserialize, Serialize};

use super::get_auth_middleware;
pub use super::home::TemplateSite;
pub use super::{context, Footer, TemplateFile, PAGES, PAYLOAD_KEY, TEMPLATES};

use crate::ctx::Ctx;
use crate::db::ForgejoWebhook;

pub mod add;
pub mod list;
pub mod view;

pub fn register_templates(t: &mut tera::Tera) {
    add::DASH_FORGEJO_WEBHOOK_ADD
        .register(t)
        .expect(add::DASH_FORGEJO_WEBHOOK_ADD.name);
    list::DASH_FORGEJO_WEBHOOK_LIST
        .register(t)
        .expect(list::DASH_FORGEJO_WEBHOOK_LIST.name);

    view::DASH_FORGEJO_WEBHOOK_VIEW
        .register(t)
        .expect(view::DASH_FORGEJO_WEBHOOK_VIEW.name);
}

pub fn services(cfg: &mut web::ServiceConfig) {
    add::services(cfg);
    list::services(cfg);
    view::services(cfg);
}

#[derive(Clone, Debug, Deserialize, Serialize, Eq, PartialEq)]
pub struct TemplateForgejoWebhook {
    pub webhook: ForgejoWebhook,
    pub view: String,
    pub url: String,
}

impl TemplateForgejoWebhook {
    pub fn new(ctx: &Ctx, hook: ForgejoWebhook) -> Self {
        let view = PAGES.dash.forgejo_webhook.get_view(&hook.auth_token);
        let url = crate::V1_API_ROUTES
            .forgejo
            .get_webhook_url(ctx, &hook.auth_token);
        Self {
            webhook: hook,
            view,
            url,
        }
    }
}
